summaryrefslogtreecommitdiffstats
path: root/khtml/rendering/render_box.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'khtml/rendering/render_box.cpp')
-rw-r--r--khtml/rendering/render_box.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/khtml/rendering/render_box.cpp b/khtml/rendering/render_box.cpp
index 7400752ac..e63115361 100644
--- a/khtml/rendering/render_box.cpp
+++ b/khtml/rendering/render_box.cpp
@@ -346,7 +346,7 @@ void RenderBox::paintRootBoxDecorations(PaintInfo& paintInfo, int _tx, int _ty)
}
if( !bgColor.isValid() && canvas()->view())
- bgColor = canvas()->view()->palette().active().color(TQColorGroup::Base);
+ bgColor = canvas()->view()->tqpalette().active().color(TQColorGroup::Base);
int w = width();
int h = height();
@@ -622,7 +622,7 @@ void RenderBox::paintBackgroundExtended(TQPainter *p, const TQColor &c, const Ba
sy+=b.y()-cy;
cx=b.x();cy=b.y();cw=b.width();ch=b.height();
}
// restrict painting to repaint-clip
if (cy < clipy) {
ch -= (clipy - cy);
sy += (clipy - cy);
@@ -795,7 +795,7 @@ void RenderBox::position(InlineBox* box, int /*from*/, int /*len*/, bool /*rever
setPos( box->xPos(), box->yPos() );
}
-void RenderBox::repaint(Priority prior)
+void RenderBox::tqrepaint(Priority prior)
{
int ow = style() ? style()->outlineSize() : 0;
if( isInline() && !isReplaced() )
@@ -622,7 +622,7 @@ void RenderBox::paintBackgroundExtended(TQPainter *p, const TQColor &c, const Ba
cx=b.x();cy=b.y();cw=b.width();ch=b.height();
}
- // restrict painting to repaint-clip
+ // restrict painting to tqrepaint-clip
if (cy < clipy) {
ch -= (clipy - cy);